Test coverage report: hero_slider.simple_translate

# hero_slider.simple_translate: 3 total statements, 100.0% covered

Generated: Thu 2013-04-18 14:15 SGT

Source file: /Users/martin/Repos/django-hero-slider/hero_slider/simple_translate.py

Stats: 1 executed, 0 missed, 2 excluded, 7 ignored

1. `"""Registering translated models for the ``hero_slider`` app."""`
2. `from simple_translation.translation_pool import translation_pool`
3. ``
4. `from hero_slider.models import (`
5. `SliderItem,`
6. `SliderItemTitle,`
7. `)`
8. ``
9. ``
10. `translation_pool.register_translation(SliderItem, SliderItemTitle)`